@@ -71,16 +71,16 @@ from .api import Api, OAuthApi, OAuth1Api, OAuth2Api
 from .async import AsyncManager, SimpleManager, QueueManager
 from .base import APP, LEVEL, NAME, VERSION, PLATFORM, API_VERSION, BUFFER_SIZE, MAX_LOG_SIZE,\
     MAX_LOG_COUNT, App, APIApp, WebApp, get_app, get_name, get_base_path, get_request,\
-    get_session, get_model, get_controller, get_adapter, get_level, is_devel, is_safe
+    get_session, get_model, get_controller, get_adapter, get_manager, get_logger, get_level, is_devel, is_safe
 from .cache import Cache, MemoryCache
 from .compress import Compress
 from .config import conf, conf_prefix, conf_s
 from .controller import Controller
-from .data import DataAdapter, MongoAdapter, Collection, MongoCollection
+from .data import DataAdapter, MongoAdapter, TinyAdapter, Collection, MongoCollection, TinyCollection
 from .defines import ITERABLES, MOBILE_REGEX, MOBILE_PREFIX_REGEX, BODY_REGEX, TAG_REGEX,\
     EMAIL_REGEX, WINDOWS_LOCALE
-from .exceptions import AppierException, OperationalError, SecurityError, ValidationError,\
-    NotFoundError, NotImplementedError, BaseInternalError, ValidationInternalError,\
+from .exceptions import AppierException, OperationalError, SecurityError, AssertionError,\
+    ValidationError, NotFoundError, NotImplementedError, BaseInternalError, ValidationInternalError,\
     ValidationMultipleError, HTTPError, APIError, APIAccessError, OAuthAccessError
 from .export import ExportManager, MongoEncoder
 from .geo import GeoResolver
@@ -108,7 +108,8 @@ from .util import is_iterable, is_mobile, email_parts, email_mime, email_name, e
     set_object, leafs, gen_token, html_to_text, camel_to_underscore, camel_to_readable, quote,\
     unquote, base_name, base_name_m, parse_cookie, parse_multipart, decode_params, load_form,\
     check_login, ensure_login, private, ensure, delayed, route, error_handler, exception_handler,\
-    before_request, after_request, is_detached, sanitize, execute, ctx_locale, FileTuple, BaseThread
+    before_request, after_request, is_detached, sanitize, verify, execute, ctx_locale, FileTuple,\
+    BaseThread
 from .validation import validate, validate_b, safe, eq, gt, gte, lt, lte, not_null, not_empty,\
     not_false, is_in, is_simple, is_email, is_url, is_regex, field_eq, field_gt, field_gte,\
     field_lt, field_lte, string_gt, string_lt, string_eq, equals, not_past, not_duplicate,\
