@@ -98,6 +98,18 @@ class SecurityError(AppierException):
 
     pass
 
+class AssertionError(OperationalError):
+    """
+    Error raised for failure to meet any pre-condition or
+    assertion for a certain data set.
+    """
+
+    def __init__(self, message = None, code = None):
+        OperationalError.__init__(self,
+            message = message or "Assertion of data failed",
+            code = code or 400
+        )
+
 class ValidationError(OperationalError):
     """
     Error raised when a validation on the model fails
@@ -113,14 +125,48 @@ class ValidationError(OperationalError):
     """ The model containing the values in it after the
     process of validation has completed """
 
-    def __init__(self, errors, model):
+    def __init__(self, errors, model, message = None, code = None):
         OperationalError.__init__(self,
-            message = "Validation of submitted data failed",
-            code = 400
+            message = message or "Validation of submitted data failed",
+            code = code or 400
         )
         self.errors = errors
         self.model = model
 
+    def __str__(self):
+        message = OperationalError.__str__(self)
+        extended = common.is_devel()
+        if not extended: return message
+        errors_s = self.errors_s()
+        if not errors_s: return message
+        errors_s = errors_s.encode("utf-8")
+        message += " (" + errors_s + ")"
+        return message
+
+    def __unicode__(self):
+        message = OperationalError.__unicode__(self)
+        extended = common.is_devel()
+        if not extended: return message
+        errors_s = self.errors_s()
+        if not errors_s: return message
+        message += " (" + errors_s + ")"
+        return message
+
+    def errors_s(self, encoding = "utf-8"):
+        if not self.errors: return ""
+        buffer = []
+        is_first = True
+        for name, errors in legacy.iteritems(self.errors):
+            for error in errors:
+                is_bytes = legacy.is_bytes(error)
+                if is_bytes: error = error.decode(encoding)
+                if is_first: is_first = False
+                else: buffer.append(", ")
+                buffer.append(name)
+                buffer.append(" => ")
+                buffer.append(error)
+        return legacy.u("").join(buffer)
+
 class NotFoundError(OperationalError):
     """
     Error originated from an operation that was not able
