@@ -71,12 +71,12 @@ in the previous document """
 
 class ExportManager(object):
 
-    db = None
+    adapter = None
     single = None
     multiple = None
 
-    def __init__(self, db, single = (), multiple = ()):
-        self.db = db
+    def __init__(self, adapter, single = (), multiple = ()):
+        self.adapter = adapter
         self.single = single
         self.multiple = multiple
 
@@ -88,7 +88,7 @@ class ExportManager(object):
         self._deploy_zip(file_path, temporary_path)
 
         for name, key in self.single:
-            collection = self.db[name]
+            collection = self.adapter.collection(name)
             source_path = os.path.join(single_path, "%s.json" % name)
             file = open(source_path, "rb")
             try: data = file.read()
@@ -104,7 +104,7 @@ class ExportManager(object):
             source_directory = os.path.join(base_path, name)
             if not os.path.exists(source_directory): continue
 
-            collection = self.db[name]
+            collection = self.adapter.collection(name)
             items = os.listdir(source_directory)
             data = []
 
@@ -131,7 +131,7 @@ class ExportManager(object):
         if not os.path.exists(single_path): os.makedirs(single_path)
 
         for name, key in self.single:
-            collection = self.db[name]
+            collection = self.adapter.collection(name)
             data = self._export_single(collection, key)
             target_path = os.path.join(single_path, "%s.json" % name)
             file = open(target_path, "wb")
@@ -139,7 +139,7 @@ class ExportManager(object):
             finally: file.close()
 
         for name, key in self.multiple:
-            collection = self.db[name]
+            collection = self.adapter.collection(name)
             data = self._export_multiple(collection, key)
 
             target_directory = os.path.join(base_path, name)
@@ -159,13 +159,16 @@ class ExportManager(object):
         data = data.decode("utf-8")
         data_s = json.loads(data)
         for _key, entity in data_s.items():
-            # verifies if the "native" object id value for the mongo
-            # database exists and if that's the case tries to convert
+            # verifies if the "native" object id value for the database
+            # definition exists and if that's the case tries to convert
             # the value from the "underlying" string value to object
-            # identifier, defaulting to a string value if it fails
+            # identifier, defaulting to a string value if it fails, note
+            # that in case the underlying identifiers does not exists a
+            # new value is generated using the pre-defined strategy
             if "_id" in entity:
-                try: entity["_id"] = bson.ObjectId(entity["_id"])
+                try: entity["_id"] = self.adapter.object_id(entity["_id"])
                 except: entity["_id"] = entity["_id"]
+            else: entity["_id"] = self.adapter.object_id()
 
             # retrieves the key value for the current entity to
             # be inserted and then tries to retrieve an existing
@@ -203,13 +206,16 @@ class ExportManager(object):
             _data = _data.decode("utf-8")
             entity = json.loads(_data)
 
-            # verifies if the "native" object id value for the mongo
-            # database exists and if that's the case tries to convert
+            # verifies if the "native" object id value for the database
+            # definition exists and if that's the case tries to convert
             # the value from the "underlying" string value to object
-            # identifier, defaulting to a string value if it fails
+            # identifier, defaulting to a string value if it fails, note
+            # that in case the underlying identifiers does not exists a
+            # new value is generated using the pre-defined strategy
             if "_id" in entity:
-                try: entity["_id"] = bson.ObjectId(entity["_id"])
+                try: entity["_id"] = self.adapter.object_id(entity["_id"])
                 except: entity["_id"] = entity["_id"]
+            else: entity["_id"] = self.adapter.object_id()
 
             # retrieves the key value for the current entity to
             # be inserted and then tries to retrieve an existing
@@ -311,5 +317,6 @@ class ExportManager(object):
 class MongoEncoder(json.JSONEncoder):
 
     def default(self, obj, **kwargs):
+        if not bson: return json.JSONEncoder.default(obj, **kwargs)
         if isinstance(obj, bson.objectid.ObjectId): return str(obj)
         else: return json.JSONEncoder.default(obj, **kwargs)
