@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Appier Framework
-# Copyright (c) 2008-2015 Hive Solutions Lda.
+# Copyright (c) 2008-2016 Hive Solutions Lda.
 #
 # This file is part of Hive Appier Framework.
 #
@@ -31,7 +31,7 @@ __revision__ = "$LastChangedRevision$"
 __date__ = "$LastChangedDate$"
 """ The last change date of the module """
 
-__copyright__ = "Copyright (c) 2008-2015 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2016 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -39,13 +39,15 @@ __license__ = "Apache License, Version 2.0"
 
 from . import util
 from . import common
+from . import legacy
 
 class Git(object):
 
     @classmethod
     def is_git(cls, path = None):
         path = path or common.base().get_base_path()
-        result = util.execute(["git", "status"], path = path)
+        try: result = util.execute(["git", "status"], path = path)
+        except OSError: return False
         code = result["code"]
         return code == 0
 
@@ -90,5 +92,20 @@ class Git(object):
         code = result["code"]
         if not code == 0: return None
         message = result.get("stdout", "")
-        commit = message.strip()
-        return commit
+        origin = message.strip()
+        origin = cls.safe_origin(origin)
+        return origin
+
+    @classmethod
+    def safe_origin(cls, origin, display_l = 3):
+        parse = legacy.urlparse(origin)
+        safe_l = []
+        if parse.scheme: safe_l.append(parse.scheme + "://")
+        if parse.username: safe_l.append(parse.username)
+        if parse.password:
+            obfuscated = util.obfuscate(parse.password)
+            safe_l.append(":" + obfuscated)
+        if parse.username: safe_l.append("@")
+        if parse.hostname: safe_l.append(parse.hostname)
+        if parse.path: safe_l.append(parse.path)
+        return "".join(safe_l)
