@@ -248,6 +248,7 @@ class Model(legacy.with_meta(meta.Ordered, observer.Observable)):
         cls = self.__class__
         default = cls.default()
         if not default: return cls._name()
+        if not default in self.model: return cls._name()
         value = self.model[default]
         if value == None: value = ""
         is_string = legacy.is_str(value)
@@ -314,7 +315,8 @@ class Model(legacy.with_meta(meta.Ordered, observer.Observable)):
         safe = True,
         build = False,
         fill = True,
-        new = True
+        new = True,
+        **kwargs
     ):
         """
         Creates a new instance of the model applying the provided model
@@ -363,7 +365,7 @@ class Model(legacy.with_meta(meta.Ordered, observer.Observable)):
         model and after the proper validations are performed on it.
         """
 
-        if model == None: model = util.get_object() if form else dict()
+        if model == None: model = util.get_object() if form else dict(kwargs)
         if fill: model = cls.fill(model)
         instance = cls()
         instance.apply(model, form = form, safe_a = safe)
@@ -1104,8 +1106,9 @@ class Model(legacy.with_meta(meta.Ordered, observer.Observable)):
         if "_safes" in cls.__dict__: return cls._safes
 
         # creates the list that will hold the various names that are
-        # meant to be safe values in the data source
-        safes = []
+        # meant to be safe values in the data source, the underlying
+        # identifier is set as the initial safe value of a model
+        safes = ["_id"]
 
         # retrieves the map containing the definition of the class with
         # the name of the fields associated with their definition
@@ -1277,15 +1280,26 @@ class Model(legacy.with_meta(meta.Ordered, observer.Observable)):
         # eager loaded from the model and runs the "resolution" process
         # for each of them so that they are properly eager loaded
         for name in names:
-            value = model[name]
-            if not value: continue
-            if not isinstance(value, TYPE_REFERENCES): continue
-            model[name] = value.resolve()
+            _model = model
+            for part in name.split("."):
+                is_sequence = type(_model) in (list, tuple)
+                if is_sequence: _model = [cls._res(value, part) for value in _model]
+                else: _model = cls._res(_model, part)
+                if not _model: break
 
         # returns the resulting model to the caller method, most of the
         # times this model should have not been touched
         return model
 
+    @classmethod
+    def _res(cls, model, part):
+        value = model[part]
+        is_reference = isinstance(value, TYPE_REFERENCES)
+        if not value and not is_reference: return value
+        if is_reference: model[part] = value.resolve()
+        model = model[part]
+        return model
+
     @classmethod
     def _get_attrs(cls, kwargs, attrs):
         _attrs = []
@@ -1585,12 +1599,27 @@ class Model(legacy.with_meta(meta.Ordered, observer.Observable)):
         # apply operation, this should trigger changes in the model
         self.post_apply()
 
+        # returns the instance that has just been used for the apply
+        # operation, this may be used for chaining operations
+        return self
+
     def copy(self, build = False, rules = True):
         cls = self.__class__
         _copy = copy.deepcopy(self)
         build and cls.build(_copy.model, map = False, rules = rules)
         return _copy
 
+    def clone(self, reset = True):
+        cls = self.__class__
+        model = self.model
+        if not reset: return cls(model = model)
+        indexes = cls.indexes()
+        indexes = indexes + ["_id"]
+        for index in indexes:
+            if not index in model: continue
+            del model[index]
+        return cls(model = model)
+
     def validate_extra(self, name):
         """
         Adds a new validate method to the current set of
@@ -1677,6 +1706,10 @@ class Model(legacy.with_meta(meta.Ordered, observer.Observable)):
         is_new and self.post_create()
         not is_new and self.post_update()
 
+        # returns the instance that has just been used for the save
+        # operation, this may be used for chaining operations
+        return self
+
     def delete(self):
         # calls the complete set of event handlers for the current
         # delete operation, this should trigger changes in the model
@@ -1709,6 +1742,10 @@ class Model(legacy.with_meta(meta.Ordered, observer.Observable)):
         method = getattr(cls, "validate" + suffix)
         self._validate(model = model, method = method)
 
+        # returns the instance that has just been used for the approve
+        # operation, this may be used for chaining operations
+        return self
+
     def reload(self, *args, **kwargs):
         is_new = self.is_new()
         if is_new: raise exceptions.OperationalError(
@@ -1727,7 +1764,7 @@ class Model(legacy.with_meta(meta.Ordered, observer.Observable)):
 
     def unwrap(self, **kwargs):
         default = kwargs.get("default", False)
-        if default: return dict(self.model)
+        if default: return self.map()
         else: return dict()
 
     def pre_validate(self):
@@ -2074,7 +2111,7 @@ def link(name = None, parameters = ()):
 
     return decorator
 
-def operation(name = None, parameters = (), level = 1):
+def operation(name = None, parameters = (), factory = False, level = 1):
     """
     Decorator function to be used to "annotate" the provided
     function as an operation that is able to change the current
@@ -2093,6 +2130,9 @@ def operation(name = None, parameters = (), level = 1):
     :param level: The severity level of the operation, the higher
     values will be considered more severe than the lower ones,
     evaluation of the value will be context based.
+    :type factory: bool
+    :param factory: If the operation is considered to be a factory
+    meaning that a new entity is going to be created and/or updated.
     :rtype: Function
     :return: The decorator function that is going to be used to
     generated the final function to be called.
@@ -2103,6 +2143,7 @@ def operation(name = None, parameters = (), level = 1):
             method = function.__name__,
             name = name or function.__name__,
             parameters = parameters,
+            factory = factory,
             level = level
         )
 
