@@ -144,6 +144,8 @@ class Request(object):
         self.result = None
         self.session = session.MockSession(self)
         self.set_cookie = None
+        self.post = {}
+        self.files = {}
         self.args = {}
         self.cookies = {}
         self.in_headers = {}
@@ -568,6 +570,9 @@ class Request(object):
     def is_success(self):
         return self.code == 200
 
+    def is_empty(self):
+        return self.code in (204, 304)
+
     @property
     def location_f(self):
         if not self.query: return self.location
