@@ -81,24 +81,25 @@ class Session(object):
         self.create = time.time()
         self.expire = self.create + self._to_seconds(expire)
         self.dirty = True
+        self.transient = dict()
 
     def __len__(self):
-        return 0
+        return self.transient.__len__()
 
     def __getitem__(self, key):
-        raise KeyError("not found")
+        return self.transient.__getitem__(key)
 
     def __setitem__(self, key, value):
-        self.mark()
+        self.mark(); self.transient.__setitem__(key, value)
 
     def __delitem__(self, key):
-        self.mark()
+        self.mark(); self.transient.__delitem__(key)
 
     def __iter__(self):
-        return iter(())
+        return self.transient.__iter__()
 
     def __contains__(self, item):
-        return False
+        return self.transient.__contains__(item)
 
     def __nonzero__(self):
         return True
@@ -106,6 +107,28 @@ class Session(object):
     def __bool__(self):
         return True
 
+    def __getstate__(self):
+        return dict(
+            sid = self.sid,
+            name = self.name,
+            address = self.address,
+            create = self.create,
+            expire = self.expire,
+            dirty = self.dirty
+        )
+
+    def __setstate__(self, state):
+        for name in (
+            "sid",
+            "name",
+            "address",
+            "create",
+            "expire",
+            "dirty"
+        ):
+            setattr(self, name, state[name])
+        self.transient = dict()
+
     @classmethod
     def new(cls, *args, **kwargs):
         return cls(*args, **kwargs)
@@ -188,6 +211,25 @@ class Session(object):
         except KeyError: value = default
         return value
 
+    def set(self, key, value):
+        self.__setitem__(key, value)
+
+    def delete(self, key, force = False):
+        if not force and not key in self: return
+        self.__delitem__(key)
+
+    def get_t(self, key, default = None):
+        try: value = self.transient[key]
+        except KeyError: value = default
+        return value
+
+    def set_t(self, key, value):
+        self.transient[key] = value
+
+    def delete_t(self, key, force = False):
+        if not force and not key in self.transient: return
+        del self.transient[key]
+
     def timeout(self):
         current = time.time()
         return self.expire - current
@@ -221,13 +263,23 @@ class MockSession(Session):
         )
         return session.__setitem__(key, value)
 
+    def __setstate__(self, state):
+        Session.__setstate__(self, state)
+        self.request = None
+
     def ensure(self, *args, **kwargs):
+        self._ensure_names(kwargs)
         session_c = self.request.session_c
         session = session_c.new(*args, **kwargs)
         self.request.session = session
         self.request.set_cookie = "sid=%s" % session.sid
         return session
 
+    def _ensure_names(self, kwargs):
+        for name in ("sid", "address"):
+            if name in kwargs: continue
+            kwargs[name] = getattr(self, name)
+
 class DataSession(Session):
 
     def __init__(self, *args, **kwargs):
@@ -235,31 +287,46 @@ class DataSession(Session):
         self.data = {}
 
     def __len__(self):
-        return self.data.__len__()
+        return Session.__len__(self) + self.data.__len__()
 
     def __getitem__(self, key):
-        return self.data.__getitem__(key)
+        try: return self.data.__getitem__(key)
+        except KeyError: return Session.__getitem__(self, key)
 
     def __setitem__(self, key, value):
         self.mark(); return self.data.__setitem__(key, value)
 
     def __delitem__(self, key):
-        self.mark(); return self.data.__delitem__(key)
+        try: self.mark(); return self.data.__delitem__(key)
+        except KeyError: return Session.__delitem__(self, key)
 
     def __iter__(self):
-        return self.data.__iter__()
+        return self._merged.__iter__()
 
     def __contains__(self, item):
-        return self.data.__contains__(item)
+        return Session.__contains__(self, item) or\
+            self.data.__contains__(item)
+
+    def __getstate__(self):
+        state = Session.__getstate__(self)
+        state.update(
+            data = self.data
+        )
+        return state
+
+    def __setstate__(self, state):
+        Session.__setstate__(self, state)
+        for name in ("data",):
+            setattr(self, name, state[name])
 
     def keys(self):
-        return self.data.keys()
+        return self._merged.keys()
 
     def values(self):
-        return self.data.values()
+        return self._merged.values()
 
     def items(self):
-        return self.data.items()
+        return self._merged.items()
 
     def sorted(self):
         keys = self.keys()
@@ -267,6 +334,15 @@ class DataSession(Session):
         keys.sort()
         return keys
 
+    @property
+    def _merged(self):
+        if not self.transient: return self.data
+        if not self.data: return self.transient
+        merged = dict()
+        merged.update(self.transient)
+        merged.update(self.data)
+        return merged
+
 class MemorySession(DataSession):
 
     SESSIONS = {}
@@ -281,13 +357,15 @@ class MemorySession(DataSession):
     @classmethod
     def new(cls, *args, **kwargs):
         session = cls(*args, **kwargs)
-        cls.SESSIONS[session.sid] = session
+        cls.SESSIONS[session.sid] = session.__getstate__()
         return session
 
     @classmethod
     def get_s(cls, sid, request = None):
-        session = cls.SESSIONS.get(sid, None)
-        if not session: return session
+        state = cls.SESSIONS.get(sid, None)
+        if not state: return state
+        session = cls.__new__(cls)
+        session.__setstate__(state)
         is_expired = session.is_expired()
         if is_expired: cls.expire(sid)
         session = None if is_expired else session
