@@ -117,6 +117,7 @@ FIND_TYPES = dict(
     find_s = legacy.UNICODE,
     find_d = to_find,
     find_i = bool,
+    find_t = legacy.UNICODE,
     sort = to_sort,
     meta = bool,
     fields = list
@@ -1140,6 +1141,13 @@ def sanitize(function, kwargs):
         removal.append(name)
     for name in removal: del kwargs[name]
 
+def verify(condition, message = None, code = None):
+    if condition: return
+    raise exceptions.AssertionError(
+        message = message,
+        code = code
+    )
+
 def execute(args, command = None, path = None, shell = None, encoding = None):
     if shell == None: shell = os.name == "nt"
     if not encoding: encoding = sys.getfilesystemencoding()
